'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

// https://github.com/reduxjs/react-redux/blob/master/src/utils/shallowEqual.js
const hasOwn = Object.prototype.hasOwnProperty;
function is(x, y) {
    if (x === y) {
        return x !== 0 || y !== 0 || 1 / x === 1 / y;
    }
    return x !== x && y !== y;
}
function shallowEqual(objA, objB) {
    if (is(objA, objB)) {
        return true;
    }
    if (typeof objA !== 'object' ||
        objA === null ||
        typeof objB !== 'object' ||
        objB === null) {
        return false;
    }
    const keysA = Object.keys(objA);
    const keysB = Object.keys(objB);
    if (keysA.length !== keysB.length) {
        return false;
    }
    for (let i = 0; i < keysA.length; i++) {
        const key = keysA[i];
        if (!hasOwn.call(objB, key) || !is(objA[key], objB[key])) {
            return false;
        }
    }
    return true;
}

function bindStore(store) {
    const dispatch = store.dispatch.bind(store);
    const getState = store.getState.bind(store);
    const subscribe = store.subscribe.bind(store);
    const connect = (mapStateToProps, propsChangedHandler) => {
        // initial props
        let props = mapStateToProps(store.getState());
        propsChangedHandler({
            newProps: props,
            prevProps: null,
            getState,
            dispatch,
        });
        return store.subscribe(() => {
            const newProps = mapStateToProps(store.getState());
            // shallow compare
            if (shallowEqual(newProps, props)) {
                return;
            }
            const prevProps = props;
            props = newProps;
            propsChangedHandler({
                newProps,
                prevProps,
                getState,
                dispatch,
            });
        });
    };
    return {
        dispatch,
        getState,
        subscribe,
        connect,
    };
}

exports.bindStore = bindStore;
